Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initialize()
→ Future<void>
-
This method is used to initialize the dependencies withing the submodules, it is called after the setUp method
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setUp(List<ISubModule> subModules)
→ dynamic
-
This method provides submodules with dependencies
to the rest of the dependencies
-
toString()
→ String
-
A string representation of this object.
inherited